@@ -5,7 +5,7 @@
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
-# Version: $Id: Convertable.pm,v 1.3 2001/12/07 17:37:16 parkerpine Exp $
+# Version: $Id: Convertable.pm,v 1.6 2002/02/21 09:06:15 parkerpine Exp $
 
 package Mail::MboxParser::Mail::Convertable;
 
@@ -16,7 +16,7 @@ use Carp;
 use strict;
 use base qw(Exporter);
 use vars qw($VERSION @EXPORT @ISA $AUTOLOAD); 
-$VERSION 	= "0.01";
+$VERSION 	= "0.02";
 @EXPORT  	= qw();
 @ISA	 	= qw(Mail::MboxParser::Base Mail::MboxParser::Mail);
 
@@ -116,11 +116,15 @@ Literally inherited from Mail::Internet. Commands can be "mail" (using the UNIX-
 
 For more details, see L<Mail::Mailer>
 
+=head1 VERSION
+
+This is version 0.31.
+
 =head1 AUTHOR AND COPYRIGHT
 
-Tassilo von Parseval <Tassilo.Parseval@post.RWTH-Aachen.de>.
+Tassilo von Parseval <tassilo.parseval@post.rwth-aachen.de>
 
-Copyright (c)  2001 Tassilo von Parseval.
+Copyright (c)  2001-2002 Tassilo von Parseval.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
